@@ -9,8 +9,8 @@ optionflags = doctest.NORMALIZE_WHITESPACE | \
               doctest.REPORT_ONLY_FIRST_FAILURE
 
 TESTFILES = [
-    'parser.txt',
-    'sphinx.txt',
+    'parser.rst',
+    'sphinx.rst',
 ]
 
 
